# Imaplar
Imaplar monitors one or more mailboxes on one or more IMAP servers
for incoming messages. When a message arrives, it is passed to a user
defined policy for processing.

See [the manual](//imaplar.readthedocs.io/en/latest/) for more information.

## Installation
Imaplar is on [PyPI](https://pypi.org/project/imaplar/),
so all you need to do is:
```
$ pip3 install imaplar
```

